  /*  signals.c - powershell
   *  Copyright (C) 1999  Matt Spong <spong@glue.umd.edu>
   *  Based from zterm.c by Michael Zucci from the libzvt docs
   *
   *  A big, puffy lotsa-shells-in-one app. 
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License
   *  along with this program; if not, write to the Free Software
   *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "powershell.h"
#include <signal.h>

void child_died_event (ZvtTerm *term)
{

  gtk_widget_hide (GTK_WIDGET(term));  
  gtk_container_remove (GTK_CONTAINER(notebook), GTK_WIDGET(term)->parent);      	
}

void term_died_event (ZvtTerm *term)
{
  zvt_term_closepty (term);

  terms_open--;
  if (!terms_open)
    gtk_main_quit();
}

void quit_proggie (GtkWidget * widget, GdkEvent * event, gpointer data)
{
  gtk_main_quit ();
}

void title_changed_event (ZvtTerm *term, VTTITLE_TYPE type, char *newtitle)
{
  printf ("title changed: %s\n", newtitle);
}

void set_hints (GtkWidget *widget)
     /*
       This function is causing problems with the window resizing,
       because it's copied from the zvt documentation and only expects
       a single terminal in the window.  Gotta fix this...
     */
{
  ZvtTerm *term;
  GdkGeometry hints;
  GtkWidget *app;
  
  g_assert (widget != NULL);
  term = ZVT_TERM (widget);
  
  app = gtk_widget_get_toplevel(widget);
  g_assert (app != NULL);
  
#define PADDING 2
  
  hints.base_width = (GTK_WIDGET (term)->style->klass->xthickness * 2) + PADDING;
  hints.base_height =  (GTK_WIDGET (term)->style->klass->ythickness * 2);
  
  hints.width_inc = term->charwidth;
  hints.height_inc = term->charheight;
  hints.min_width = hints.base_width + hints.width_inc;
  hints.min_height = hints.base_height + hints.height_inc;
  
  gtk_window_set_geometry_hints(GTK_WINDOW(app),
				GTK_WIDGET(term),
				&hints,
				GDK_HINT_RESIZE_INC|GDK_HINT_MIN_SIZE|GDK_HINT_BASE_SIZE);
}


void NotebookHandler (GtkNotebook * notebook, GtkNotebookPage * page,
		      gint page_num, gpointer user_data)
/******************************************************
This function is lame... but it works.  Could be done
a hell of a lot better.
******************************************************/

{
  GtkWidget * tmp;
  gchar ** tmp2;
  gchar tmp3[512];

  tmp = gtk_notebook_get_tab_label (GTK_NOTEBOOK(notebook), 
				    gtk_notebook_get_nth_page (GTK_NOTEBOOK(notebook), 
							       page_num));
  gtk_label_get (GTK_LABEL(tmp), (gchar **)(&tmp2));
  sprintf (tmp3, "PowerShell - [%s]", tmp2);

  gtk_window_set_title (GTK_WINDOW(window), tmp3); 
}


void MenuHandler (GtkWidget * w, gchar * data)
{
  char command[512], args[512];
  char * tmp;
  GtkWidget * curpage;

  if ((int)data < 64)
    {
      bzero (command, 512);
      bzero (args, 512);

      tmp = strstr (app_entries[(int)data-1].command, " ");
      if (!tmp)
	strcpy (command, app_entries[(int)data-1].command);
      else
	{
	  *tmp = '\0';
	  strcpy (command, app_entries[(int)data-1].command);
	  *tmp = ' ';
	  tmp++;
	  strcpy (args, tmp);
	}
      new_term (GTK_WIDGET(notebook), command, args, app_entries[(int)data-1].tab_title);
      return;
    }


  switch ((int)data)
    {
      /* file menu */

    case 99:
      gtk_main_quit();
      break;
      
      /* edit menu */
    case 101:     /* Edit->Cut */
      break;
    case 102:     /* Edit->Copy */
      break;
    case 103:     /* Edit->Paste */
      break;
    case 104:     /* Edit->Preferences */
      DoPreferences();
      break;
      
    case 210:     /* rename term */
      RenameTerm();
      break;
      /* help menu */
    case 1001:    /* Help->About */
      AboutDialog();
      break;

    }
  
  if ((int)data / 100 == 2)
    {
      gtk_notebook_set_page (GTK_NOTEBOOK(notebook), (int)data - 201);
    }
  
}


gboolean term_key_event (GtkWidget * widget, GdkEventKey * event, gpointer user_data)
{
  if (event->state & 4)
    {
      if ((event->keyval > 48) && (event->keyval < 58))
	{
	  gtk_notebook_set_page (GTK_NOTEBOOK(notebook), event->keyval - 49);
	  event->state = event->keyval = event->length = 0;
	  event->string = NULL;

	  return TRUE;
	}
    }

  return FALSE;
}


gint term_click_event (GtkWidget * widget, GdkEventButton * event)
{
  char * URL;
  char * type;
  char buf[512];
  char buf2[512];

  int char_x = (int)event->x / ZVT_TERM(widget)->charwidth;
  int char_y = (int)event->y / ZVT_TERM(widget)->charheight;

  if (event->button > 1)
    {
      RenameTerm();
    }

  else

    if (URL = zvt_term_match_check (ZVT_TERM(widget), char_x, char_y, (void **)(&type)))
      {
	
	if (!strcmp (type, "http"))
	  new_term (notebook, Prefs.http_handler, URL, "http");
	if (!strcmp (type, "ftp"))
	  new_term (notebook, Prefs.ftp_handler, URL, "ftp");
	if (!strcmp (type, "mailto"))
	  {
	    sprintf (buf2, "compose to %s", URL);
	    new_term (notebook, Prefs.mail_handler, URL, buf2);
	  }      
	if (!strcmp (type, "telnet"))
	  {
	    strcpy (buf, URL+9);
	    sprintf (buf2, "telnet %s", buf);
	    new_term (notebook, Prefs.telnet_handler, buf, buf2);
	  }
	
      }
}
